==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsVisualMenuOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsVisualMenuOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsVisualMenuOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsVisualMenuOptionArgsBuilder internal constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("fmmfmydfncxkulqp")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("scaxrikkkdphpuwi")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsVisualMenuOptionArgs =
        DashboardDashboardPublishOptionsVisualMenuOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsVisualMenuOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsVisualMenuOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsVisualMenuOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsVisualMenuOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsVisualMenuOptionArgsBuilder internal constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("oxfrkvaxfiuvaqwn")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("xpecghrqdatkmhtq")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsVisualMenuOptionArgs =
        DashboardDashboardPublishOptionsVisualMenuOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}
